@@ -1,7 +1,7 @@
 package Module::XSOrPP;
 
-our $DATE = '2015-05-22'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,6 +19,7 @@ our @EXPORT_OK = qw(
                );
 
 our @XS_OR_PP_MODULES = qw(
+                              Params::Validate
                               Params::Util
                               List::MoreUtils
 );
@@ -146,7 +147,7 @@ Module::XSOrPP - Determine if an installed module is XS or pure-perl
 
 =head1 VERSION
 
-This document describes version 0.09 of Module::XSOrPP (from Perl distribution Module-XSOrPP), released on 2015-05-22.
+This document describes version 0.10 of Module::XSOrPP (from Perl distribution Module-XSOrPP), released on 2015-10-20.
 
 =head1 SYNOPSIS
 
@@ -229,7 +230,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Module-XSO
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Module-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Module-XSOrPP>.
 
 =head1 BUGS
 
